import oracledb from 'oracledb'
import environment from '../../config/Environment.js'
import { log } from '../Controllers/LogController.js'

const libDir = process.env.LD_LIBRARY_PATH
if (libDir) oracledb.initOracleClient({ libDir })

const organizationPools = new Map()

async function initializePool(nrorg = 1) {
    nrorg = 1106; // temp solution
    const config = environment.getConnectionData(nrorg)
    try {
        console.log(config)
        const newPool = await oracledb.createPool(config)
        organizationPools.set(nrorg, newPool)
        log({ type: 'info', message: `Database pool initialized for organization: ${nrorg}` })
        return newPool
    } catch (err) {
        log({ type: 'error', message: `Error initializing database pool:\n${err.message}` })
        throw err
    }
}

async function getPoolById(nrorg = 1) {
    nrorg = 1106; // temp solution
    if (organizationPools.has(nrorg)) {
        try {
            const pool = organizationPools.get(nrorg)
            const connection = await pool.getConnection()
            const result = await connection.execute('SELECT 1 FROM DUAL')
            await connection.release()
            return pool
        } catch (err) {
            // The pool is not alive or the connection is not valid
            // removing invalid pool and creating a new one
            log({ type: 'error', message: `Error checking pool health:\n${err.message}` })
            organizationPools.delete(nrorg)
        }
    }

    return initializePool(nrorg)
}

export { initializePool, getPoolById }
